@@ -19,14 +19,13 @@ tokens = (
 'SQRT',
 'NUMBER',
 'POW',
-'SUB'
 )
 
 t_VAR = r'(a|b|c|x|y|z|m|n)'
 t_PLUS = r'\+'
 t_MIN   = r'\-'
-t_OPENC   = r'(\{|\\{)'
-t_CLOSEDC  = r'(\}|\\})'
+t_OPENC   = r'\{'
+t_CLOSEDC  = r'\}'
 t_OPENP  = r'\('
 t_CLOSEDP  = r'\)'
 t_OPENCO = r'\['
@@ -39,7 +38,6 @@ t_SQRT = r'\\sqrt'
 t_NUMBER = r'[0-9]+(?:\.[0-9]+)?'
 # t_NUMBER = r'^([0-9]+(?:\.[0-9]+)?)$'
 t_POW = r'\^'
-t_SUB = '_'
 
 t_ignore = ' '
 
