@@ -16,7 +16,7 @@ def LatexParse(latex):
         acceptance.append('p_el_er_eq_er')
 
     def p_el_er_neq_er(p):
-        'EL : ER NEQ ER'
+        'EL : ER  NEQ ER'
         acceptance.append('p_el_er_neq_er')
 
     def p_el_er_eq(p):
@@ -27,6 +27,14 @@ def LatexParse(latex):
         'EL : ER NEQ'
         acceptance.append('p_el_er_neq')
 
+    def p_el_plus_er(q):
+        'EL : PLUS ER'
+        acceptance.append('p_el_plus_er')
+
+    def p_el_minus_er(q):
+        'EL : MIN ER'
+        acceptance.append('p_el_min_er')
+
     def p_el_er(q):
         'EL : ER'
         acceptance.append('p_el_er')
@@ -43,29 +51,13 @@ def LatexParse(latex):
         'ER : T'
         acceptance.append('p_er_t')
 
-    def p_er_t_subsc_cdot_t(p):
-        'T : SUBSC CDOT T'
-        acceptance.append('p_er_t_subsc_cdot_t')
+    def p_t_t_cdot_pw(p):
+        'T : PW CDOT T'
+        acceptance.append('p_t_t_cdot_pw')
 
-    def p_er_t_subsc(p):
-        'T : SUBSC '
-        acceptance.append('p_er_t_subsc')
-
-    def p_er_subsc_pw_sub_subsc(p):
-        'SUBSC : PW SUB SUBSC'
-        acceptance.append('p_er_subsc_pw_sub_subsc')
-
-    def p_er_subsc_pw(p):
-        'SUBSC : PW'
-        acceptance.append('p_er_subsc_pw')
-
-    # def p_t_t_cdot_pw(p):
-    #     'T : PW CDOT T'
-    #     acceptance.append('p_t_t_cdot_pw')
-
-    # def p_t_pw(p):
-    #     'T : PW'
-    #     acceptance.append('p_t_pw')
+    def p_t_pw(p):
+        'T : PW'
+        acceptance.append('p_t_pw')
 
     def p_pw_pw_pow_fr(p):
         'PW : FR POW PW'
@@ -99,14 +91,6 @@ def LatexParse(latex):
         'S : S F'
         acceptance.append('p_s_f')
 
-    def p_s_plus_f(p):
-        'S : PLUS F'
-        acceptance.append('p_s_lus_f')
-
-    def p_s_min_f(p):
-        'S : MIN F'
-        acceptance.append('p_s_min_f')
-
     def p_s_f(p):
         'S : F'
         acceptance.append('p_s_f')
@@ -148,6 +132,18 @@ def LatexParse(latex):
 
         print("Syntax error in input!", p)
 
+        # print('... ', dir(parser))
+        # print('\n')
+        # print(parser.symstack)
+        # print('\n')
+
+        # stack_state_str = ' '.join([symbol.type for symbol in parser.symstack][1:])
+
+        # print('Syntax error in input! Parser State:{} {} . {}'
+        #     .format(parser.state,
+        #             stack_state_str,
+        #             p))
+
         erro = {
             'lexpos': None,
             'lineno': None,
